Function glory_core::web::widgets::iframe
source · pub fn iframe() -> HtmlIframeExpand description
The <iframe> HTML element represents a nested browsing context, embedding another HTML page into the current one.
pub fn iframe() -> HtmlIframeThe <iframe> HTML element represents a nested browsing context, embedding another HTML page into the current one.