Function glory_core::web::widgets::math
source · pub fn math() -> HtmlMathExpand description
The top-level element in MathML is <math>. Every valid MathML instance must be mapped in <math> tags. In addition you must not nest a second <math> element in another, but you can have an arbitrary number of other child elements in it.