Function glory_core::web::widgets::object
source · pub fn object() -> HtmlObjectExpand description
The <object> HTML element represents an external resource, which can be treated as an image, a nested browsing context, or a resource to be handled by a stuffin.