Struct glory_core::web::widgets::HtmlInput
source · pub struct HtmlInput(pub Element);Tuple Fields
0: ElementImplementations
sourceimpl HtmlInput
impl HtmlInput
sourcepub fn auto_capitalize(self, value: impl PropValue + 'static) -> Self
pub fn auto_capitalize(self, value: impl PropValue + 'static) -> Self
A shortcut to set property autocapitalize.
sourcepub fn default_value(self, value: impl PropValue + 'static) -> Self
pub fn default_value(self, value: impl PropValue + 'static) -> Self
A shortcut to set property defaultValue.
sourcepub fn dir_name(self, value: impl PropValue + 'static) -> Self
pub fn dir_name(self, value: impl PropValue + 'static) -> Self
A shortcut to set property dirName.
sourcepub fn input_mode(self, value: impl PropValue + 'static) -> Self
pub fn input_mode(self, value: impl PropValue + 'static) -> Self
A shortcut to set property inputmode.
sourcepub fn multiple(self, value: impl PropValue + 'static) -> Self
pub fn multiple(self, value: impl PropValue + 'static) -> Self
A shortcut to set property multiple.
sourcepub fn popover_target_action(self, value: impl PropValue + 'static) -> Self
pub fn popover_target_action(self, value: impl PropValue + 'static) -> Self
A shortcut to set property popoverTargetAction.
sourcepub fn popover_target_element(self, value: impl PropValue + 'static) -> Self
pub fn popover_target_element(self, value: impl PropValue + 'static) -> Self
A shortcut to set property popoverTargetElement.
sourcepub fn value_as_date(self, value: impl PropValue + 'static) -> Self
pub fn value_as_date(self, value: impl PropValue + 'static) -> Self
A shortcut to set property valueAsDate.
sourcepub fn value_as_number(self, value: impl PropValue + 'static) -> Self
pub fn value_as_number(self, value: impl PropValue + 'static) -> Self
A shortcut to set property valueAsNumber.
pub fn new() -> HtmlInput
pub fn fill(self, filler: impl IntoFiller) -> Self
pub fn then<F>(self, func: F) -> Selfwhere F: FnOnce(Self) -> Self,
pub fn id<V>(self, value: V) -> Selfwhere V: AttrValue + 'static,
pub fn class<V>(self, value: V) -> Selfwhere V: ClassPart + 'static,
pub fn toggle_class<V, C>(self, value: V, cond: C) -> Selfwhere V: Into<String>, C: Into<Lotus<bool>>,
pub fn switch_class<TV, FV, C>(self, tv: TV, fv: FV, cond: C) -> Selfwhere TV: Into<String>, FV: Into<String>, C: Into<Lotus<bool>>,
sourcepub fn prop<V>(self, name: impl Into<Cow<'static, str>>, value: V) -> Selfwhere
V: PropValue + 'static,
pub fn prop<V>(self, name: impl Into<Cow<'static, str>>, value: V) -> Selfwhere V: PropValue + 'static,
Adds an property to this element.
sourcepub fn attr<V>(self, name: impl Into<Cow<'static, str>>, value: V) -> Selfwhere
V: AttrValue + 'static,
pub fn attr<V>(self, name: impl Into<Cow<'static, str>>, value: V) -> Selfwhere V: AttrValue + 'static,
Adds an attribute to this element.
sourcepub fn on<E, H>(self, event: E, handler: H) -> Selfwhere
E: EventDescriptor + 'static,
H: FnMut(E::EventType) + 'static,
pub fn on<E, H>(self, event: E, handler: H) -> Selfwhere E: EventDescriptor + 'static, H: FnMut(E::EventType) + 'static,
Adds an event listener to this element.
pub fn text<V>(self, text: V) -> Selfwhere V: AttrValue + 'static,
sourcepub fn html<V>(self, html: V) -> Selfwhere
V: AttrValue + 'static,
pub fn html<V>(self, html: V) -> Selfwhere V: AttrValue + 'static,
Sets the inner HTML of this element from the provided string slice.
Security
Be very careful when using this method. Always remember to sanitize the input to avoid a cross-site scripting (XSS) vulnerability.
pub fn node_ref(self, node_ref: &NodeRef<Node>) -> Self
Methods from Deref<Target = Element>
pub fn node(&self) -> &Node
pub fn add_filler(&mut self, filler: impl IntoFiller)
pub fn is_void(&self) -> bool
pub fn add_id<V>(&mut self, value: V)where V: AttrValue + 'static,
pub fn add_class<V>(&mut self, value: V)where V: ClassPart + 'static,
sourcepub fn add_prop<V>(&mut self, name: impl Into<Cow<'static, str>>, value: V)where
V: PropValue + 'static,
pub fn add_prop<V>(&mut self, name: impl Into<Cow<'static, str>>, value: V)where V: PropValue + 'static,
Adds an property to this element.
sourcepub fn add_attr<V>(&mut self, name: impl Into<Cow<'static, str>>, value: V)where
V: AttrValue + 'static,
pub fn add_attr<V>(&mut self, name: impl Into<Cow<'static, str>>, value: V)where V: AttrValue + 'static,
Adds an attribute to this element.
sourcepub fn add_event_listener<E: EventDescriptor>(
&self,
_event: E,
_event_handler: impl FnMut(E::EventType) + 'static
)
pub fn add_event_listener<E: EventDescriptor>( &self, _event: E, _event_handler: impl FnMut(E::EventType) + 'static )
Adds an event listener to this element.