Module glory_core::spawn
source · Functions
- The microtask is a short function which will run after the current task has completed its work and when there is no other code waiting to be run before control of the execution context is returned to the browser’s event loop.
- Spawns and runs a thread-local
Futurein a platform-independent way.