Function glory_core::web::widgets::embed
source · pub fn embed() -> HtmlEmbedExpand description
The <embed> HTML element embeds external content at the specified point in the document. This content is provided by an external application or other source of interactive content such as a browser stuff-in.