Function glory_core::web::widgets::html
source · pub fn html() -> HtmlHtmlExpand description
The <html> HTML element represents the root (top-level element) of an HTML document, so it is also referred to as the root element. All other elements must be descendants of this element.